
// uart.c implementation file
//---------------------------
#include <stdio.h>
#include <unistd.h>
#include <fcntl.h>
#include <termios.h>

static int uart0_filestream;

int uart_open(char* pdevice)
//===========================
{
	struct termios options;
	uart0_filestream=-1;
	uart0_filestream=open(pdevice,O_RDWR|O_NOCTTY|O_NDELAY);
	if (uart0_filestream==-1)
	{
		printf("Error: Unable to open UART.\r\n");
		return uart0_filestream;
	}
	tcgetattr(uart0_filestream,&options);
	options.c_cflag=B9600|CS8|CLOCAL|CREAD;
	options.c_iflag=IGNPAR;
	options.c_oflag=0;
	options.c_lflag=0;
	tcflush(uart0_filestream,TCIFLUSH);
	tcsetattr(uart0_filestream,TCSANOW,&options);
	return 0;
}

int uart_close(void)
//===================
{
	close(uart0_filestream);
	return 0;
}

int uart_transmit(char* buffer, unsigned int length)
//====================================================
{
	int count;
	if (uart0_filestream==-1)
	{
		printf("Error: UART is not open.\r\n");
		return 1;
	}
	count=write(uart0_filestream,buffer,length);
	if (count!=length)
	{
		printf("Error: Write to UART failed.\r\n");
		return 1;
	}
	printf("%s\r\n",buffer);
	return 0;
}

int uart_receive(char* buffer, unsigned int* length)
//====================================================
{
	int count;
	if (uart0_filestream==-1)
	{
		printf("Error: UART is not open.\r\n");
		return 1;
	}
	count=read(uart0_filestream,buffer,255);
	if (count<0)
	{
		return 1;
	}
	*length=count;
	return 0;
}
